@@ -120,26 +120,13 @@
     Plotting
     ^^^^^^^^
 
-    SST_Data Reference
-    ------------------
+    Reference
+    ---------
 
     Methods
     ^^^^^^^
 
-    .. list-table:: Title
-       :widths: 25 25 50
-       :header-rows: 1
-
-       * - Heading row 1, column 1
-         - Heading row 1, column 2
-         - Heading row 1, column 3
-       * - Row 1, column 1
-         -
-         - Row 1, column 3
-       * - Row 2, column 1
-         - Row 2, column 2
-         - Row 2, column 3
-
+    
 
     Attributes
     ^^^^^^^^^^
