@@ -179,7 +179,31 @@ ma_info = np.array(
         (52, 270, np.array([6.39169242e+05, 6.69769247e+06, 1.82180000e+02]), 1014,   23.5),
         (53, 340, np.array([6.39199806e+05, 6.69768286e+06, 1.82226000e+02]), 1014,   23.5),
         (54, 310, np.array([6.39223589e+05, 6.69770809e+06, 1.82158000e+02]), 1106,   23.5),
-        (55, 90,  np.array([6.39216821e+05, 6.69765166e+06, 1.82178000e+02]), 1106,   23.5)
+        (55, 90,  np.array([6.39216821e+05, 6.69765166e+06, 1.82178000e+02]), 1106,   23.5),
+        (56, 0 , np.array([639166.449,  6697659.027, 182.023]), 0, 0),
+        (57, 0 , np.array([639215.343,  6697624.231, 182.616]), 0, 0),
+        (58, 0 , np.array([639212.511,  6697596.767, 182.589]), 0, 0),
+        (59, 0 , np.array([639172.087,  6697554.41 , 182.618]), 0, 0),
+        (60, 0 , np.array([639195.287,  6697539.278, 182.613]), 0, 0),
+        (61, 0 , np.array([639149.311,  6697537.968, 182.608]), 0, 0),
+        (62, 0 , np.array([639213.407,  6697485.116, 182.655]), 0, 0),
+        (63, 0 , np.array([639199.459,  6697454.733, 182.642]), 0, 0),
+        (64, 0 , np.array([638925.579,  6697597.428, 181.486]), 0, 0),
+        (65, 0 , np.array([638863.841,  6697563.347, 181.296]), 0, 0),
+        (66, 0 , np.array([638821.425,  6697535.168, 181.236]), 0, 0),
+        (67, 0 , np.array([638970.031,  6697540.574, 181.772]), 0, 0),
+        (68, 0 , np.array([638951.341,  6697490.638, 181.764]), 0, 0),
+        (69, 0 , np.array([638902.989,  6697486.95 , 181.178]), 0, 0),
+        (70, 0 , np.array([638924.864,  6697452.932, 181.232]), 0, 0),
+        (71, 0 , np.array([638987.56 ,  6697461.71 , 181.782]), 0, 0),
+        (72, 0 , np.array([638997.129,  6697545.429, 181.801]), 0, 0),
+        (73, 0 , np.array([639004.298,  6697518.733, 181.772]), 0, 0),
+        (74, 0 , np.array([639081.531,  6697491.281, 182.587]), 0, 0),
+        (75, 0 , np.array([639042.344,  6697460.205, 181.792]), 0, 0),
+        (76, 0 , np.array([639120.224,  6697452.406, 182.605]), 0, 0),
+        (77, 0 , np.array([639046.268,  6697413.41 , 181.881]), 0, 0),
+        (78, 0 , np.array([639114.382,  6697512.751, 182.602]), 0, 0),
+        (79, 0 , np.array([639158.051,  6697404.906, 182.415]), 0, 0),
     ],
     np.dtype(
         [
